!----------------------------------------------------------------------*
!  SUBROUTINE SUBDDN                                                   *
!  Purpose: This subroutine calculates the daily amount of heat units  *
!           (0-1, normalised) for calculation of the phenological      *
!           development rate and early leaf area growth.               *
!  Author : Pepijn van Oort                                            *
!  Date   : 30/10/2013                                                 *
!                                                                      *
! FORMAL PARAMETERS:  (I=input,O=output,C=control,IN=init,T=time)      *
! name   type meaning (unit)                                     class *
! ----   ---- ---------------                                    ----- *
! TMAX    R4  Daily maximum temperature (oC)                        I  *
! TMIN    R4  Daily minimum temperature (oC)                        I  *
! TBD     R4  Base temperature for development (oC)                 I  *
! TOD     R4  Optimum temperature for development (oC)              I  *
! TMD     R4  Maximum temperature for development (oC)              I  *
! HU      R4  Heat units (d)                                        O  *
!                                                                      *
!  FILE usage : none                                                   *
!----------------------------------------------------------------------*
      SUBROUTINE SUBDDN(TMAX,TMIN,TBD,TOD,TMD,HU)

      IMPLICIT NONE
!-----Formal parameters
      REAL    TMAX,TMIN,TBD,TOD,TMD,HU
!-----Local parameters
      REAL    TD, TM, TT
      INTEGER I
      SAVE
 
      TM = (TMAX+TMIN)/2.
      TT = 0.
      DO I = 1,24
         TD = TM+0.5*ABS(TMAX-TMIN)*COS(0.2618*FLOAT(I-14))
 
!         IF ((TD.GT.TBD).AND.(TD.LT.TMD)) THEN
!            IF (TD.GT.TOD) TD = TOD-(TD-TOD)*(TOD-TBD)/(TMD-TOD)
!            TT = TT+(TD-TBD)/24.
!         END IF
          IF ((TD.GT.TBD).AND.(TD.LT.TMD)) THEN
             IF (TD.LT.TOD) THEN 
                TT=TT+(TD-TBD)/(TOD-TBD)
             ELSE
                TT=TT+(TMD-TD)/(TMD-TOD)
            END IF
          END IF
 
      END DO
      HU = TT/24.
 
      RETURN
      END
